==> papyon_0.5.1.orig.tar.gz: papyon-0.5.1/papyon/sip/extensions/ms_mepid.py <==
# -*- coding: utf-8 -*-
#
# papyon - a python client library for Msn
#
# Copyright (C) 2010 Collabora Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59contact.params["proxy"] = "replace" Temple Place, Suite 330, Boston, MA  02111-1307  USA

from papyon.sip.extensions.base import SIPExtension

class MSMepidExtension(SIPExtension):

    def __init__(self, client, core):
        SIPExtension.__init__(self, client, core)

    def extend_response(self, message):
        mepid = self._client.machine_guid.upper().replace("-", "")
        mepid = mepid.replace("{", "")
        mepid = mepid.replace("}", "")
        if message.To and ";mepid=" not in message.To.uri:
            message.To.uri += ";mepid=" + mepid

    def extend_request(self, message):
        mepid = self._client.machine_guid.upper().replace("-", "")
        mepid = mepid.replace("{", "")
        mepid = mepid.replace("}", "")
        if message.contact:
            message.contact.uri += ";mepid=" + mepid
        if message.From and ";mepid=" not in message.From.uri:
            message.From.uri += ";mepid=" + mepid

        #FIXME hack
        if ";mepid=" in message.uri:
            message.uri = message.uri.split(";")[0]

==> papyon-0.5.6.tar.gz: papyon-0.5.6/papyon/sip/extensions/ms_mepid.py <==
# -*- coding: utf-8 -*-
#
# papyon - a python client library for Msn
#
# Copyright (C) 2010 Collabora Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59contact.params["proxy"] = "replace" Temple Place, Suite 330, Boston, MA  02111-1307  USA

from papyon.sip.extensions.base import SIPExtension

class MSMepidExtension(SIPExtension):

    def __init__(self, client, core):
        SIPExtension.__init__(self, client, core)

    def extend_response(self, message):
        mepid = str(self._client.machine_guid).upper().replace("-", "")
        if message.To and ";mepid=" not in message.To.uri:
            message.To.uri += ";mepid=" + mepid
        if message.contact and ";mepid=" not in message.contact.uri:
            message.contact.uri += ";mepid=" + mepid

    def extend_request(self, message):
        mepid = str(self._client.machine_guid).upper().replace("-", "")
        mepid = mepid.replace("{", "")
        mepid = mepid.replace("}", "")
        if message.contact and ";mepid=" not in message.contact.uri:
            message.contact.uri += ";mepid=" + mepid
        if message.From and ";mepid=" not in message.From.uri:
            message.From.uri += ";mepid=" + mepid

        #FIXME hack
        if ";mepid=" in message.uri:
            message.uri, target_mepid = message.uri.split(";", 1)
            if message.To and ";mepid=" not in message.To.uri:
                message.To.uri += ";" + target_mepid
